/* 
 * tplay - buffered audio player header file
 *
 * (c) 1997 ilkka karvinen <ik@iki.fi>
 *
 * Copyright under the GNU GENERAL PUBLIC LICENSE
 *   (see the file COPYING in this directory)
 *
 */

#ifndef __COMMON_H
#define __COMMON_H
#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>
#include <string.h>
#include <sys/ioctl.h>
#include <errno.h>
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

/* Audio driver */
#if defined (linux) || defined (__FreeBSD__) || defined (__OpenBSD__) || defined (__bsdi__) 
#define AUDIO_OSS
#endif
#if defined (sun)
#define AUDIO_SUN
#endif

/* Default audio parameters */
#define DEFAULT_BITS     16
#define DEFAULT_SPEED    44100
#define DEFAULT_CHANNELS 2

/* Audio memory pool. 512k is the default. */
#define BUFFER_SIZE    0x80000 

/* The minimum and maximum buffer block sizes. */
#if 0
#define MIN_BLOCK_SIZE 0x4000  /* 16k */
#else
#define MIN_BLOCK_SIZE 4096
#endif
#define MAX_BLOCK_SIZE 0x10000 /* 64k */

#ifndef TRUE
#define TRUE  1
#define FALSE 0
#endif

/* The maximum retry count for buffer fill tries. */
#define RETRY_COUNT 5

/* Magics. Little-endian. */
#define RIFF_MAGIC    0x46464952 /* ASCII: 'RIFF' */
#define WAVE_MAGIC    0x45564157 /* ASCII: 'WAVE' */
#define DATA_MAGIC    0x61746164 /* ASCII: 'data' */
#define INFO_MAGIC    0x4f464e49 /* ASCII: 'INFO' */
#ifdef sparc
#define SUN_INV_MAGIC 0x2e736e64 /* ASCII: '.snd' */

/* Magics. Big-endian. */
#define SUN_MAGIC     0x646e732e /* ASCII: '.snd' */
#else
#define SUN_MAGIC     0x2e736e64 /* ASCII: '.snd' */

/* Magics. Big-endian. */
#define SUN_INV_MAGIC 0x646e732e /* ASCII: '.snd' */
#endif

/* Sun headersize */
#define SUN_HDRSIZE 24

/* File types */
#define UNKNOWN_FILE  0
#define RIFF_FILE     1
#define SUN_FILE      2

typedef unsigned char byte;
typedef unsigned long DWORD;
typedef unsigned short WORD;

/* Circular buffer info structure of audio data blocks. */
/* declared in tplay.c                                  */
struct info_struct {
  byte *buffer;                /* the audio data */
  byte *firstblock;            /* pointer to the first block */
  long readcount, writecount;
  int alldone;
  int skip;
  double sseconds;
  unsigned int skip_size;      /* size to skip */
  int in_seconds;
  double seconds;
  int blocksize;               /* size of one block */
  int buffer_size;             /* size of the buffer */
  int number_of_blocks;
  int last_block;              /* -1 if not the last block */
  int bytes_on_last_block;
  int writeblock;
  int swap;
  int forceraw;
  int force;
  int filetype;
  int headerskip;
  int audioset;
  int show_usage;
  int speed;
  int channels;
  int bits;
  int encoding;
  int audio_fd;                /* Audio device descriptor */
  int file_fd;                 /* Audio file descriptor */
  char *progname;
  char *device;                /* Audio device name */
  int loop;
  int verbose;
  int optind;
  int capacity;
  int framesize;
  int framecount;
};

/* au.c */
extern int read_au(byte *buffer);
extern int write_au(byte *buffer, int speed, int bits, int channels);

/* wav.c */
extern int read_wav(byte *buffer);

/* common.c */
extern DWORD read_big_endian_long(byte *buffer);
extern void  write_big_endian_long(byte *buffer, DWORD value);
extern DWORD read_little_endian_long(byte *buffer);
extern WORD read_little_endian_word(byte *buffer);
extern void errprintf(char *fmt, ...);
extern void usage(void);
extern void warning(char *str);
extern void warning2(char *str1, char *str2);
extern void die(char *str);
extern void errdie(char *str);
extern void open_audio();
extern void set_audio_parameters();
extern void sync_audio(void);
extern void reset_audio(void);
extern void post_audio(void);
extern void close_audio(void);
extern void open_file(char *file);
extern void close_file(void);
extern void destroy_buffer(void);
extern void nice_fputc(int c, FILE *fp);
#if defined(sun)
extern char *basename(char *name);
#endif
/* audio_*.c */
extern void set_audio_parameters();
extern void sync_audio(void);
extern void reset_audio(void);
extern void post_audio(void);
extern void close_audio(void);

/* Global variables */
extern int verbose;
extern struct info_struct info;

#endif
